@@ -1,4 +1,3 @@
-#!/usr/bin/env perl
 package Path::Dispatcher::Dispatch;
 use Moose;
 use MooseX::AttributeHelpers;
@@ -32,6 +31,9 @@ sub run {
         eval {
             local $SIG{__DIE__} = 'DEFAULT';
 
+            $match->rule->trace(running => 1, match => $match)
+                if $ENV{PATH_DISPATCHER_TRACE};
+
             push @results, scalar $match->run(@args);
 
             die "Path::Dispatcher abort\n"
