@@ -1,10 +1,9 @@
-#!/usr/bin/env perl
 package Path::Dispatcher::Rule;
 use Moose;
 
 use Path::Dispatcher::Match;
 
-sub match_class { "Path::Dispatcher::Match" }
+use constant match_class => "Path::Dispatcher::Match";
 
 has block => (
     is        => 'rw',
@@ -18,12 +17,23 @@ has prefix => (
     default => 0,
 );
 
+has name => (
+    is        => 'rw',
+    isa       => 'Str',
+    predicate => 'has_name',
+);
+
 sub match {
     my $self = shift;
     my $path = shift;
 
     my ($result, $leftover) = $self->_match($path);
-    return unless $result;
+
+    if (!$result) {
+        $self->trace(leftover => $leftover, match => undef, path => $path)
+            if $ENV{'PATH_DISPATCHER_TRACE'};
+        return;
+    }
 
     $leftover = '' if !defined($leftover);
 
@@ -45,6 +55,8 @@ sub match {
         leftover => $leftover,
     );
 
+    $self->trace(match => $match) if $ENV{'PATH_DISPATCHER_TRACE'};
+
     return $match;
 }
 
@@ -56,6 +68,57 @@ sub run {
     $self->block->(@_);
 }
 
+sub readable_attributes { }
+
+sub trace {
+    my $self  = shift;
+    my %args  = @_;
+
+    my $level = $ENV{'PATH_DISPATCHER_TRACE'};
+
+    return if exists($args{level})
+           && $level < $args{level};
+
+    my $match = $args{match};
+    my $path  = $match ? $match->path : $args{path};
+
+    # name
+    my $trace = '';
+    if ($self->has_name) {
+        $trace .= $self->name;
+    }
+    else {
+        $trace .= "$self";
+    }
+
+    # attributes such as tokens or regex
+    if ($level >= 2) {
+        my $attr = $self->readable_attributes;
+        $trace .= " $attr" if defined($attr) && length($attr);
+    }
+
+    # what just happened
+    if ($args{running}) {
+        $trace .= " running codeblock with path ($path)";
+        if ($level >= 10) {
+            require B::Deparse;
+            $trace .= ": " . B::Deparse->new->coderef2text($match->rule->block);
+        }
+    }
+    elsif ($match) {
+        $trace .= " matched against ($path)";
+        $trace .= " with (" . $match->leftover . ") left over"
+            if length($match->leftover);
+    }
+    else {
+        $trace .= " did not match against ($path)";
+    }
+
+    $trace .= ".\n";
+
+    warn $trace;
+}
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
@@ -64,6 +127,9 @@ require Path::Dispatcher::Rule::Always;
 require Path::Dispatcher::Rule::CodeRef;
 require Path::Dispatcher::Rule::Dispatch;
 require Path::Dispatcher::Rule::Empty;
+require Path::Dispatcher::Rule::Eq;
+require Path::Dispatcher::Rule::Intersection;
+require Path::Dispatcher::Rule::Metadata;
 require Path::Dispatcher::Rule::Regex;
 require Path::Dispatcher::Rule::Tokens;
 require Path::Dispatcher::Rule::Under;
