@@ -1,4 +1,3 @@
-#!/usr/bin/env perl
 package Path::Dispatcher::Rule::Dispatch;
 use Moose;
 extends 'Path::Dispatcher::Rule';
@@ -17,6 +16,8 @@ sub match {
     return $dispatch->matches;
 }
 
+sub readable_attributes { shift->dispatcher->name }
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 no Moose::Util::TypeConstraints;
