@@ -1,4 +1,3 @@
-#!/usr/bin/env perl
 package Path::Dispatcher::Rule::Regex;
 use Moose;
 extends 'Path::Dispatcher::Rule';
@@ -13,9 +12,9 @@ sub _match {
     my $self = shift;
     my $path = shift;
 
-    return unless $path =~ $self->regex;
+    return unless $path->path =~ $self->regex;
 
-    my @matches = map { substr($path, $-[$_], $+[$_] - $-[$_]) } 1 .. $#-;
+    my @matches = map { substr($path->path, $-[$_], $+[$_] - $-[$_]) } 1 .. $#-;
 
     # if $' is in the program at all, then it slows down every single regex
     # we only want to include it if we have to
@@ -26,6 +25,8 @@ sub _match {
     return \@matches;
 }
 
+sub readable_attributes { shift->regex }
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
